@@ -115,3 +115,6 @@ class Vulnerability(Object):
                     not hodgepodge.time.in_range(timestamp, min_timestamp, max_timestamp):
                 return False
         return True
+
+    def __hash__(self):
+        return self.id
